@@ -4,7 +4,6 @@
 #endif
 
 #include <stdint.h>
-#include <time.h>
 #include "ft2_header.h"
 #include "ft2_config.h"
 #include "ft2_about.h"
@@ -203,7 +202,7 @@ bool setupGUI(void)
 	}
 
 	setPal16(palTable[config.cfg_StdPalNum], false);
-	seedAboutScreenRandom((uint32_t)time(NULL));
+	initAboutScreen();
 	setupInitialTextBoxPointers();
 	setInitialTrimFlags();
 	initializeScrollBars();
@@ -349,6 +348,9 @@ void charOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 {
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
+	if ((uint8_t)chr > 127+31)
+		chr = ' ';
+
 	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
@@ -374,6 +376,9 @@ void charOutBg(uint16_t xPos, uint16_t yPos, uint8_t fgPalette, uint8_t bgPalett
 {
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
+	if ((uint8_t)chr > 127+31)
+		chr = ' ';
+
 	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
@@ -408,6 +413,9 @@ void charOutShadow(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, uint8_t s
 {
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
+	if ((uint8_t)chr > 127+31)
+		chr = ' ';
+
 	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
@@ -442,6 +450,9 @@ void charOutClipX(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr,
 	if (xPos > clipX)
 		return;
 
+	if ((uint8_t)chr > 127+31)
+		chr = ' ';
+
 	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
@@ -471,6 +482,9 @@ void bigCharOut(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex, char chr)
 {
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
+	if ((uint8_t)chr > 127+31)
+		chr = ' ';
+
 	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
@@ -496,6 +510,9 @@ static void bigCharOutShadow(uint16_t xPos, uint16_t yPos, uint8_t paletteIndex,
 {
 	assert(xPos < SCREEN_W && yPos < SCREEN_H);
 
+	if ((uint8_t)chr > 127+31)
+		chr = ' ';
+
 	chr &= 0x7F; // this is important to get the nordic glyphs in the font
 	if (chr == ' ')
 		return;
