@@ -24,6 +24,7 @@
 #include "ft2_audio.h"
 #include "ft2_trim.h"
 #include "ft2_sample_ed_features.h"
+#include "ft2_midi.h"
 #include "ft2_structs.h"
 
 keyb_t keyb; // globalized
@@ -69,6 +70,11 @@ void readKeyModifiers(void)
 	keyb.leftCommandPressed = (modState & KMOD_LGUI) ? true : false;
 #endif
 	keyb.keyModifierDown = (modState & (KMOD_LSHIFT | KMOD_LCTRL | KMOD_LALT | KMOD_LGUI)) ? true : false;
+
+
+#ifdef _WIN32
+	keyb.leftWinKeyDown = (modState & KMOD_LGUI) ? true : false;
+#endif
 }
 
 void keyUpHandler(SDL_Scancode scancode, SDL_Keycode keycode)
@@ -339,7 +345,7 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 
 			if (!ui.nibblesShown     && !ui.configScreenShown &&
 				!ui.aboutScreenShown && !ui.diskOpShown       &&
-				!ui.helpScreenShown  && !ui.extended)
+				!ui.helpScreenShown  && !ui.extendedPatternEditor)
 			{
 				drawIDAdd();
 			}
@@ -558,7 +564,7 @@ static void handleKeys(SDL_Keycode keycode, SDL_Scancode scanKey)
 		break;
 
 		// PATTERN EDITOR POSITION KEYS
-
+		
 		case SDLK_INSERT:
 		{
 			if (keyb.leftShiftPressed)
@@ -699,16 +705,18 @@ static bool checkModifiedKeys(SDL_Keycode keycode)
 		case SDLK_KP_ENTER:
 		case SDLK_RETURN:
 		{
-			if (keyb.leftAltPressed)
+			if (keyb.leftAltPressed && !keyb.leftCtrlPressed)
 			{
 				toggleFullscreen();
-
-				// prevent fullscreen toggle from firing twice on certain SDL2 Linux ports
-#ifdef __unix__
-				SDL_Delay(100);
-#endif
 				return true;
 			}
+			else if (keyb.leftCommandPressed || keyb.leftCtrlPressed)
+			{
+				if (keyb.leftShiftPressed)
+					insertPatternLine();
+				else
+					insertPatternNote();
+			}
 		}
 		break;
 
@@ -901,7 +909,7 @@ static bool checkModifiedKeys(SDL_Keycode keycode)
 				video.showFPSCounter ^= 1;
 				if (!video.showFPSCounter)
 				{
-					if (ui.extended) // yet another kludge...
+					if (ui.extendedPatternEditor) // yet another kludge...
 						exitPatternEditorExtended();
 
 					showTopScreen(false);
@@ -1154,7 +1162,7 @@ static bool checkModifiedKeys(SDL_Keycode keycode)
 			}
 			else if (keyb.leftCtrlPressed)
 			{
-				if (ui.extended)
+				if (ui.extendedPatternEditor)
 					exitPatternEditorExtended();
 
 				if (ui.sampleEditorShown)    hideSampleEditor();
@@ -1285,16 +1293,15 @@ static bool checkModifiedKeys(SDL_Keycode keycode)
 
 				return true;
 			}
-#ifdef HAS_MIDI
 			else if (keyb.leftCtrlPressed)
 			{
+#ifdef HAS_MIDI
 				editor.currConfigScreen = 3;
 				showConfigScreen();
 				checkRadioButton(RB_CONFIG_MIDI_INPUT);
-
+#endif
 				return true;
 			}
-#endif
 		}
 		break;
 
