@@ -23,6 +23,7 @@
 #include "ft2_sample_ed.h"
 #include "ft2_diskop.h"
 #include "scopes/ft2_scopes.h"
+#include "scopes/ft2_scopedraw.h"
 #include "ft2_about.h"
 #include "ft2_pattern_ed.h"
 #include "ft2_module_loader.h"
@@ -146,7 +147,7 @@ int main(int argc, char *argv[])
 #ifdef __APPLE__
 	osxSetDirToProgramDirFromArgs(argv);
 #endif
-	if (!setupExecutablePath() || !loadBMPs() || !calcCubicSplineTable() || !calcWindowedSincTables())
+	if (!setupExecutablePath() || !loadBMPs() || !setupQuadraticSplineTable() || !setupCubicSplineTable() || !setupWindowedSincTables())
 	{
 		cleanUpAndExit();
 		return 1;
@@ -205,7 +206,6 @@ int main(int argc, char *argv[])
 		return 1;
 	}
 
-	initAboutScreen();
 	pauseAudio();
 	resumeAudio();
 	rescanAudioDevices();
@@ -367,6 +367,7 @@ static void cleanUpAndExit(void) // never call this inside the main loop!
 	freeTextBoxes();
 	freeMouseCursors();
 	freeBMPs();
+	freeScopeIntrpLUT();
 
 	if (editor.audioDevConfigFileLocationU != NULL)
 	{
