@@ -12,10 +12,10 @@
 
 extern const uint16_t ptPeriods[3 * 12];
 
-extern const uint8_t arpTab[256];
+extern const uint8_t arpeggioTab[256];
 extern const int8_t autoVibSineTab[256];
-extern const uint8_t vibTab[32];
-extern const uint16_t amigaPeriod[8 * 12];
+extern const uint8_t vibratoTab[32];
+extern const uint16_t modPeriods[8 * 12];
 extern const uint16_t linearPeriods[1936];
 extern const uint16_t amigaPeriods[1936];
 
